@@ -4,7 +4,7 @@
 package Net::Frame::Layer::SNMP;
 use strict; use warnings;
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 use Net::Frame::Layer qw(:consts :subs);
 use Exporter;
@@ -352,7 +352,7 @@ sub getKeyReverse { shift->layer }
 sub getLength {    
    my $self = shift;
 
-   return length($self->raw)
+   return length($self->pack)
 }
 
 sub pack {
@@ -384,10 +384,10 @@ sub pack {
       }
    } elsif ($self->pdu_type == NF_SNMP_PDUTYPE_TRAP) {
       my $agent_addr;
-      if ($self->agent_addr =~ /:/) {
-         $agent_addr = inet6Aton($self->agent_addr)
+      if ($self->agentAddr =~ /:/) {
+         $agent_addr = inet6Aton($self->agentAddr)
       } else {
-         $agent_addr = inetAton($self->agent_addr)
+         $agent_addr = inetAton($self->agentAddr)
       }
       $raw = $snmpasn->encode(
          version   => $self->version,
@@ -655,28 +655,10 @@ sub v2trap_varbinds {
 
 sub _inetNtoa {
     my ($addr) = @_;
-
-    if ($Socket::VERSION >= 1.94) {
-        my $name;
-        if (length($addr) == 4) {
-            $name = Socket::pack_sockaddr_in(0, $addr)
-        } else {
-            $name = Socket::pack_sockaddr_in6(0, $addr)
-        }
-        my ($err, $address) = Socket::getnameinfo($name, $NI_NUMERICHOST);
-        if (defined($address)) {
-            return $address
-        } else {
-            # print "getnameinfo($addr) failed - $err";
-            return undef
-        }
+    if (length($addr) == 4) {
+        return inet_ntoa($addr)
     } else {
-        if (length($addr) == 4) {
-            return inet_ntoa($addr)
-        } else {
-            # Poor man's IPv6
-            return join ':', (CORE::unpack '(a4)*', CORE::unpack ('H*', $addr))
-        }
+        return inet6Ntoa($addr)
     }
 }
 
